@@ -22,12 +22,12 @@ public:
     explicit GotifyPushProvider(QObject *parent = nullptr);
 
     bool loadSettings(const QSettings &settings) override;
-    void connectToProvider() override;
+    void connectToProvider(Urgency urgency) override;
     void disconnectFromProvider() override;
     void registerClient(const Client &client) override;
     void unregisterClient(const Client &client) override;
 
-    static constexpr const char Id[] = "Gotify";
+    static constexpr inline auto Id = QLatin1StringView("Gotify");
 private:
     void wsMessageReceived(const QString &msg);
 
